elasticdsl: elasticdsl: An Elasticsearch DSL R client.

elasticdslR Documentation

elasticdsl: An Elasticsearch DSL R client.

Security

Elasticsearch is insecure out of the box! If you are running Elasticsearch locally on your own machine without exposing a port to the outside world, no worries, but if you install on a server with a public IP address, take the necessary precautions. There are a few options:

Author(s)

Scott Chamberlain

Examples

## Not run: 
# start Elasticsearch, then connect
elastic::connect()

# Search on the index 'shakespeare', and for the prefix 'we'
index("shakespeare") %>% query("prefix", speaker = "we")

## End(Not run)


ropensci/elasticdsl documentation built on May 18, 2022, 9:53 a.m.