filter: elastic DSL filters

View source: R/filter.R

filterR Documentation

elastic DSL filters

Description

new setup, not quite ready yet this will require queries to be passed inside this function call to indicate that you want a query to be a filter type query

Usage

filter(x)

Arguments

.obj

An index object. If nothing passed defaults to all indices, equivalent to doing e.g., localhost:9200/_search

...

xxxx

Examples

## Not run: 
filter(term, speaker = "KING HENRY IV")

## End(Not run)

ropensci/elasticdsl documentation built on May 18, 2022, 9:53 a.m.