| tabl | R Documentation |
Attempt to coerce output to a single data.frame
tabl(x, source_only = TRUE, n = 10)
x |
Input |
source_only |
(logical) Return source only? |
n |
(integer) Count to print. |
Note that this may not always succeed, as we can't predict what various ways your data in formatted in your Elasticsearch instance.
## Not run:
elastic::connect()
index("shakespeare") %>%
prefix(speaker = "we") %>%
size(200) %>% tabl()
x <- index("shakespeare") %>%
filter() %>%
range(line_number <= 20) %>%
size(200) %>%
exec
x %>% tabl()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.