| elasticdsl | R Documentation |
Elasticsearch is insecure out of the box! If you are running Elasticsearch locally on your own machine without exposing a port to the outside world, no worries, but if you install on a server with a public IP address, take the necessary precautions. There are a few options:
Shield https://www.elastic.co/products/shield - This is a paid product - so probably only applicable to enterprise users
DIY security - there are a variety of techniques for securing your Elasticsearch. I collected a number of resources in a blog post at http://recology.info/2015/02/secure-elasticsearch/
Scott Chamberlain
## Not run:
# start Elasticsearch, then connect
elastic::connect()
# Search on the index 'shakespeare', and for the prefix 'we'
index("shakespeare") %>% query("prefix", speaker = "we")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.