| filter | R Documentation |
new setup, not quite ready yet this will require queries to be passed inside this function call to indicate that you want a query to be a filter type query
filter(x)
.obj |
An index object. If nothing passed defaults to all indices, equivalent to
doing e.g., |
... |
xxxx |
## Not run: filter(term, speaker = "KING HENRY IV") ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.